@@ -54,6 +54,7 @@ typedef struct tds_connection TDSCONNECTION;
 typedef struct tds_socket TDSSOCKET;
 typedef struct tds_column TDSCOLUMN;
 typedef struct tds_bcpinfo TDSBCPINFO;
+typedef struct tds_result_info TDSRESULTINFO;
 
 #include <freetds/version.h>
 #include <freetds/sysdep_private.h>
@@ -540,24 +541,24 @@ typedef struct tds_login
 
 	unsigned char option_flag2;
 
-	unsigned int bulk_copy:1;	/**< if bulk copy should be enabled */
-	unsigned int suppress_language:1;
-	unsigned int gssapi_use_delegation:1;
-	unsigned int mutual_authentication:1;
-	unsigned int use_ntlmv2:1;
-	unsigned int use_ntlmv2_specified:1;
-	unsigned int use_lanman:1;
-	unsigned int mars:1;
-	unsigned int use_utf16:1;
-	unsigned int use_new_password:1;
-	unsigned int valid_configuration:1;
-	unsigned int check_ssl_hostname:1;
-	unsigned int readonly_intent:1;
-	unsigned int enable_tls_v1:1;
-	unsigned int enable_tls_v1_specified:1;
-	unsigned int enable_tls_v1_1:1;
-	unsigned int enable_tls_v1_1_specified:1;
-	unsigned int server_is_valid:1;
+	uint8_t bulk_copy:1;	/**< if bulk copy should be enabled */
+	uint8_t suppress_language:1;
+	uint8_t gssapi_use_delegation:1;
+	uint8_t mutual_authentication:1;
+	uint8_t use_ntlmv2:1;
+	uint8_t use_ntlmv2_specified:1;
+	uint8_t use_lanman:1;
+	uint8_t mars:1;
+	uint8_t use_utf16:1;
+	uint8_t use_new_password:1;
+	uint8_t valid_configuration:1;
+	uint8_t check_ssl_hostname:1;
+	uint8_t readonly_intent:1;
+	uint8_t enable_tls_v1:1;
+	uint8_t enable_tls_v1_specified:1;
+	uint8_t enable_tls_v1_1:1;
+	uint8_t enable_tls_v1_1_specified:1;
+	uint8_t server_is_valid:1;
 } TDSLOGIN;
 
 typedef struct tds_headers
@@ -708,18 +709,18 @@ struct tds_column
 	DSTR table_column_name;
 
 	unsigned char *column_data;
-	void (*column_data_free)(struct tds_column *column);
-	unsigned char column_nullable:1;
-	unsigned char column_writeable:1;
-	unsigned char column_identity:1;
-	unsigned char column_key:1;
-	unsigned char column_hidden:1;
-	unsigned char column_output:1;
-	unsigned char column_timestamp:1;
-	unsigned char column_computed:1;
+	void (*column_data_free)(struct tds_column * column);
+	uint8_t column_nullable:1;
+	uint8_t column_writeable:1;
+	uint8_t column_identity:1;
+	uint8_t column_key:1;
+	uint8_t column_hidden:1;
+	uint8_t column_output:1;
+	uint8_t column_timestamp:1;
+	uint8_t column_computed:1;
 	TDS_UCHAR column_collation[5];
 
-	unsigned char use_iconv_out:1;
+	uint8_t use_iconv_out:1;
 
 	/* additional fields flags for compute results */
 	TDS_SMALLINT column_operand;
@@ -759,7 +760,7 @@ struct tds_column
 
 
 /** Hold information for any results */
-typedef struct tds_result_info
+struct tds_result_info
 {
 	/* TODO those fields can became a struct */
 	TDSCOLUMN **columns;
@@ -768,7 +769,7 @@ typedef struct tds_result_info
 	TDS_INT ref_count;
 	TDSSOCKET *attached_to;
 	unsigned char *current_row;
-	void (*row_free)(struct tds_result_info* result, unsigned char *row);
+	void (*row_free)(TDSRESULTINFO* result, unsigned char *row);
 	TDS_INT row_size;
 
 	TDS_SMALLINT *bycolumns;
@@ -776,7 +777,7 @@ typedef struct tds_result_info
 	bool rows_exist;
 	/* TODO remove ?? used only in dblib */
 	bool more_results;
-} TDSRESULTINFO;
+};
 
 /** values for tds->state */
 typedef enum tds_states
@@ -862,7 +863,7 @@ enum TDS_DBG_LOG_STATE
 };
 #endif
 
-typedef struct tds_result_info TDSCOMPUTEINFO;
+typedef TDSRESULTINFO TDSCOMPUTEINFO;
 
 typedef TDSRESULTINFO TDSPARAMINFO;
 
@@ -1115,12 +1116,12 @@ struct tds_connection
 	TDS_UCHAR tds72_transaction[8];
 
 	TDS_CAPABILITIES capabilities;
-	unsigned int use_iconv_in:1;
-	unsigned int tds71rev1:1;
-	unsigned int pending_close:1;	/**< true is connection has pending closing (cursors or dynamic) */
-	unsigned int encrypt_single_packet:1;
+	uint8_t use_iconv_in:1;
+	uint8_t tds71rev1:1;
+	uint8_t pending_close:1;	/**< true is connection has pending closing (cursors or dynamic) */
+	uint8_t encrypt_single_packet:1;
 #if ENABLE_ODBC_MARS
-	unsigned int mars:1;
+	uint8_t mars:1;
 
 	TDSSOCKET *in_net_tds;
 	TDSPACKET *packets;
@@ -1130,7 +1131,7 @@ struct tds_connection
 
 #define BUSY_SOCKET ((TDSSOCKET*)(TDS_UINTPTR)1)
 #define TDSSOCKET_VALID(tds) (((TDS_UINTPTR)(tds)) > 1)
-	struct tds_socket **sessions;
+	TDSSOCKET **sessions;
 	unsigned num_sessions;
 #endif
 	tds_mutex list_mtx;
@@ -1198,7 +1199,7 @@ struct tds_socket
 	 * The buffer is actually a bit larger to make possible to do some
 	 * optimizations (at least TDS_ADDITIONAL_SPACE bytes).
 	 */
-	unsigned int out_buf_max;
+	unsigned out_buf_max;
 	unsigned in_pos;		/**< current position in in_buf */
 	unsigned out_pos;		/**< current position in out_buf */
 	unsigned in_len;		/**< input buffer length */
@@ -1694,6 +1695,10 @@ typedef struct tds5_colinfo
 	TDS_TINYINT status;
 	TDS_SMALLINT offset;
 	TDS_INT length;
+	bool dflt;
+
+	TDS_INT dflt_size;
+	TDS_UCHAR* dflt_value;
 } TDS5COLINFO;
 
 struct tds_bcpinfo
